==> ejc-accplat-impl-3.0.0-20231225.023258-50-sources.jar: com/ejianc/business/kingdee/test/InvokeHelper.java <==
package com.ejianc.business.kingdee.test;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;


/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
@Slf4j
public class InvokeHelper {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static String POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";

    // Cookie 值
    private static String CookieVal = null;


    private static Map map = new HashMap();

    static {
        map.put("Save",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Save.common.kdsvc");
        map.put("View",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.View.common.kdsvc");
        map.put("Delete",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Delete.common.kdsvc");
        map.put("Submit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Submit.common.kdsvc");
        map.put("Audit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Audit.common.kdsvc");
        map.put("UnAudit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.UnAudit.common.kdsvc");
        map.put("StatusConvert",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.StatusConvert.common.kdsvc");
    }


    private static HttpURLConnection initUrlConn(String url, JSONArray paras)
            throws Exception {
        URL postUrl = new URL(POST_K3CloudURL.concat(url));
        HttpURLConnection connection = (HttpURLConnection) postUrl
                .openConnection();
        if (CookieVal != null) {
            connection.setRequestProperty("Cookie", CookieVal);
        }
        if (!connection.getDoOutput()) {
            connection.setDoOutput(true);
        }
        connection.setRequestMethod("POST");
        connection.setUseCaches(false);
        connection.setInstanceFollowRedirects(true);
        connection.setRequestProperty("Content-Type", "application/json");
        DataOutputStream out = new DataOutputStream(
                connection.getOutputStream());

        UUID uuid = UUID.randomUUID();
        int hashCode = uuid.toString().hashCode();

        JSONObject jObj = new JSONObject();

        jObj.put("format", 1);
        jObj.put("useragent", "ApiClient");
        jObj.put("rid", hashCode);
        jObj.put("parameters", chinaToUnicode(paras.toString()));
        jObj.put("timestamp", new Date().toString());
        jObj.put("v", "1.0");

        out.writeBytes(jObj.toString());
        out.flush();
        out.close();

        return connection;
    }

    // Login
    public static boolean Login(String dbId, String user, String pwd, int lang)
            throws Exception {

        boolean bResult = false;

        String sUrl = "Kingdee.BOS.WebApi.ServicesStub.AuthService.ValidateUser.common.kdsvc";

        JSONArray jParas = new JSONArray();
        jParas.add(dbId);// 帐套Id
        jParas.add(user);// 用户名
        jParas.add(pwd);// 密码
        jParas.add(lang);// 语言
        System.out.println(JSONObject.toJSONString(jParas));
        HttpURLConnection connection = initUrlConn(sUrl, jParas);
        // 获取Cookie
        String key = null;
        for (int i = 1; (key = connection.getHeaderFieldKey(i)) != null; i++) {
            if (key.equalsIgnoreCase("Set-Cookie")) {
                String tempCookieVal = connection.getHeaderField(i);
                if (tempCookieVal.startsWith("kdservice-sessionid")) {
                    CookieVal = tempCookieVal;
                    break;
                }
            }
        }

        BufferedReader reader = new BufferedReader(new InputStreamReader(
                connection.getInputStream()));
        String line;
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ");
        System.out.println(" ============================= ");
        while ((line = reader.readLine()) != null) {
            String sResult = new String(line.getBytes(), "utf-8");
            System.out.println(sResult);
            bResult = line.contains("\"LoginResultType\":1");
        }
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ends ");
        System.out.println(" ============================= ");
        reader.close();

        connection.disconnect();

        return bResult;
    }

    // Save
    public static void Save(String formId, String content) throws Exception {
        Invoke("Save", formId, content);
    }

    // View
    public static void View(String formId, String content) throws Exception {
        Invoke("View", formId, content);
    }

    // Delete
    public static void Delete(String formId, String content) throws Exception {
        Invoke("Delete", formId, content);
    }

    // Submit
    public static void Submit(String formId, String content) throws Exception {
        Invoke("Submit", formId, content);
    }

    // Audit
    public static void Audit(String formId, String content) throws Exception {
        Invoke("Audit", formId, content);
    }

    // UnAudit
    public static void UnAudit(String formId, String content) throws Exception {
        Invoke("UnAudit", formId, content);
    }

    // StatusConvert
    public static void StatusConvert(String formId, String content)
            throws Exception {
        Invoke("StatusConvert", formId, content);
    }

    private static void Invoke(String deal, String formId, String content)
            throws Exception {

        String sUrl = map.get(deal).toString();
        JSONArray jParas = new JSONArray();
        jParas.add(formId);
        jParas.add(content);

        HttpURLConnection connectionInvoke = initUrlConn(sUrl, jParas);

        BufferedReader reader = new BufferedReader(new InputStreamReader(
                connectionInvoke.getInputStream()));

        String line;
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ");
        System.out.println(" ============================= ");
        while ((line = reader.readLine()) != null) {
            String sResult = new String(line.getBytes(), "utf-8");
            System.out.println(sResult);
        }
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ends ");
        System.out.println(" ============================= ");
        reader.close();

        connectionInvoke.disconnect();
    }

    /**
     * 把中文转成Unicode码
     *
     * @param str
     * @return
     */
    public static String chinaToUnicode(String str) {
        String result = "";
        for (int i = 0; i < str.length(); i++) {
            int chr1 = (char) str.charAt(i);
            if (chr1 >= 19968 && chr1 <= 171941) {// 汉字范围 \u4e00-\u9fa5 (中文)
                result += "\\u" + Integer.toHexString(chr1);
            } else {
                result += str.charAt(i);
            }
        }
        return result;
    }
}

==> ejc-accplat-impl-3.0.0-20231229.082139-55-sources.jar: com/ejianc/business/kingdee/test/InvokeHelper.java <==
package com.ejianc.business.kingdee.test;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.kingdee.api.K3CloudObjectTypeAdapter;
import com.ejianc.business.kingdee.base.response.RepoError;
import com.ejianc.business.kingdee.base.response.RepoRet;
import com.ejianc.business.voucher.utils.DataConvertUtil;
import com.ejianc.framework.core.exception.BusinessException;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonParser;
import lombok.extern.slf4j.Slf4j;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.InputStreamReader;
import java.lang.reflect.Type;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.*;


/**
 * @description: TODO
 * @author songlx
 * @date 2023/12/12
 * @version 1.0
 */
@Slf4j
public class InvokeHelper {

    // http://123.234.41.174:8090/k3cloud/html5/index.aspx
    //账号 ：徐慧/666666  选世纪阳光测试账套
    public static String POST_K3CloudURL = "http://123.234.41.174:8090/K3Cloud/";

    // Cookie 值
    private static String CookieVal = null;


    private static Map map = new HashMap();

    static {
        map.put("Save",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Save.common.kdsvc");
        map.put("View",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.View.common.kdsvc");
        map.put("Delete",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Delete.common.kdsvc");
        map.put("Submit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Submit.common.kdsvc");
        map.put("Audit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.Audit.common.kdsvc");
        map.put("UnAudit",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.UnAudit.common.kdsvc");
        map.put("StatusConvert",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.StatusConvert.common.kdsvc");
        map.put("ExecuteBillQuery",
                "Kingdee.BOS.WebApi.ServicesStub.DynamicFormService.ExecuteBillQuery.common.kdsvc");
    }


    private static HttpURLConnection initUrlConn(String url, JSONArray paras)
            throws Exception {
        URL postUrl = new URL(POST_K3CloudURL.concat(url));
        HttpURLConnection connection = (HttpURLConnection) postUrl
                .openConnection();
        if (CookieVal != null) {
            connection.setRequestProperty("Cookie", CookieVal);
        }
        if (!connection.getDoOutput()) {
            connection.setDoOutput(true);
        }
        connection.setRequestMethod("POST");
        connection.setUseCaches(false);
        connection.setInstanceFollowRedirects(true);
        connection.setRequestProperty("Content-Type", "application/json");
        DataOutputStream out = new DataOutputStream(
                connection.getOutputStream());

        UUID uuid = UUID.randomUUID();
        int hashCode = uuid.toString().hashCode();

        JSONObject jObj = new JSONObject();

        jObj.put("format", 1);
        jObj.put("useragent", "ApiClient");
        jObj.put("rid", hashCode);
        jObj.put("parameters", chinaToUnicode(paras.toString()));
        jObj.put("timestamp", new Date().toString());
        jObj.put("v", "1.0");

        out.writeBytes(jObj.toString());
        out.flush();
        out.close();

        return connection;
    }

    // Login
    public static boolean Login(String dbId, String user, String pwd, int lang)
            throws Exception {

        boolean bResult = false;

        String sUrl = "Kingdee.BOS.WebApi.ServicesStub.AuthService.ValidateUser.common.kdsvc";

        JSONArray jParas = new JSONArray();
        jParas.add(dbId);// 帐套Id
        jParas.add(user);// 用户名
        jParas.add(pwd);// 密码
        jParas.add(lang);// 语言
        System.out.println(JSONObject.toJSONString(jParas));
        HttpURLConnection connection = initUrlConn(sUrl, jParas);
        // 获取Cookie
        String key = null;
        for (int i = 1; (key = connection.getHeaderFieldKey(i)) != null; i++) {
            if (key.equalsIgnoreCase("Set-Cookie")) {
                String tempCookieVal = connection.getHeaderField(i);
                if (tempCookieVal.startsWith("kdservice-sessionid")) {
                    CookieVal = tempCookieVal;
                    break;
                }
            }
        }

        BufferedReader reader = new BufferedReader(new InputStreamReader(
                connection.getInputStream()));
        String line;
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ");
        System.out.println(" ============================= ");
        while ((line = reader.readLine()) != null) {
            String sResult = new String(line.getBytes(), "utf-8");
            System.out.println(sResult);
            bResult = line.contains("\"LoginResultType\":1");
        }
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ends ");
        System.out.println(" ============================= ");
        reader.close();

        connection.disconnect();

        return bResult;
    }

    // Save
    public static void Save(String formId, String content) throws Exception {
        Invoke("Save", formId, content);
    }

    // View
    public static void View(String formId, String content) throws Exception {
        Invoke("View", formId, content);
    }

    // Delete
    public static void Delete(String formId, String content) throws Exception {
        Invoke("Delete", formId, content);
    }

    // Submit
    public static void Submit(String formId, String content) throws Exception {
        Invoke("Submit", formId, content);
    }

    // Audit
    public static void Audit(String formId, String content) throws Exception {
        Invoke("Audit", formId, content);
    }

    // UnAudit
    public static void UnAudit(String formId, String content) throws Exception {
        Invoke("UnAudit", formId, content);
    }

    // StatusConvert
    public static void StatusConvert(String formId, String content)
            throws Exception {
        Invoke("StatusConvert", formId, content);
    }

    public static List<Map<String, Object>> executeBillQuery(String content, String fieldKeys) {
        return invokeQuery("ExecuteBillQuery", content, fieldKeys);
    }

    private static List<Map<String, Object>> invokeQuery(String deal, String content, String fieldKeys) {
        String sUrl = map.get(deal).toString();
        JSONArray jParas = new JSONArray();
        jParas.add(content);
        String json = null;
        try {
            HttpURLConnection connectionInvoke = initUrlConn(sUrl, jParas);
            BufferedReader reader = new BufferedReader(new InputStreamReader(connectionInvoke.getInputStream()));
            String line;
            log.info(" ============================= ");
            log.info("金蝶云星空接口发送参数:" + content);
            log.info(" ============================= ");
            while ((line = reader.readLine()) != null) {
                json = new String(line.getBytes(), "utf-8");
            }
            log.info(" ============================= ");
            log.info("金蝶云星空接口返回结果:" + DataConvertUtil.toPrettyFormat(json));
            log.info(" ============================= ");

            reader.close();
            connectionInvoke.disconnect();

        } catch (Exception e) {
            e.printStackTrace();
        }

        try {
            (new JsonParser()).parse(json).getAsJsonArray();
        } catch (Exception var6) {
            throw new BusinessException("json parse error, response: [" + json + "]", var6);
        }

        if (json.indexOf(",\"IsSuccess\":false,") > -1) {
            throw new BusinessException(loadErrorMsg(json));
        } else {
            return loadDataList(json, fieldKeys);
        }
    }

    public static String loadErrorMsg(String json) {
        if (json.startsWith("[[") && json.endsWith("]]")) {
            Gson gson = new Gson();
            return ((RepoError) ((RepoRet) gson.fromJson(json.substring(2, json.length() - 2), RepoRet.class)).getResult().getResponseStatus().getErrors().get(0)).getMessage();
        } else {
            return String.format("fail for ExecuteBillQuery:%s", json);
        }
    }

    public static Gson buildGson(Type type) {
        Gson gs = new Gson();
        K3CloudObjectTypeAdapter adapter = new K3CloudObjectTypeAdapter(gs);
        Gson gson = (new GsonBuilder()).registerTypeAdapter(type, adapter).create();
        return gson;
    }


    protected static List<Map<String, Object>> loadDataList(String json, String fieldKeys) {
        List<Map<String, Object>> rets = new ArrayList();
        Gson gson = buildGson(ArrayList.class);
        List<ArrayList<Object>> rows = (List) gson.fromJson(json, rets.getClass());
        String[] fields = fieldKeys.split(",");
        Iterator var11 = rows.iterator();
        try {
            while (var11.hasNext()) {
                List<Object> darray = (List) var11.next();
                Map map = new HashMap<String, Object>();
                for (int i = 0; i < fields.length; ++i) {
                    map.put(fields[i], darray.get(i));
                }
                rets.add(map);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        return rets;
    }


    private static void Invoke(String deal, String formId, String content)
            throws Exception {

        String sUrl = map.get(deal).toString();
        JSONArray jParas = new JSONArray();
        jParas.add(formId);
        jParas.add(content);

        HttpURLConnection connectionInvoke = initUrlConn(sUrl, jParas);

        BufferedReader reader = new BufferedReader(new InputStreamReader(
                connectionInvoke.getInputStream()));

        String line;
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ");
        System.out.println(" ============================= ");
        while ((line = reader.readLine()) != null) {
            String sResult = new String(line.getBytes(), "utf-8");
            System.out.println(DataConvertUtil.toPrettyFormat(sResult));
        }
        System.out.println(" ============================= ");
        System.out.println(" Contents of post request ends ");
        System.out.println(" ============================= ");
        reader.close();

        connectionInvoke.disconnect();
    }

    /**
     * 把中文转成Unicode码
     *
     * @param str
     * @return
     */
    public static String chinaToUnicode(String str) {
        String result = "";
        for (int i = 0; i < str.length(); i++) {
            int chr1 = (char) str.charAt(i);
            if (chr1 >= 19968 && chr1 <= 171941) {// 汉字范围 \u4e00-\u9fa5 (中文)
                result += "\\u" + Integer.toHexString(chr1);
            } else {
                result += str.charAt(i);
            }
        }
        return result;
    }
}
